%============================================================================
%
% Diffraction Coefficients versus Diffraction Angle
%
% Input parameter
%
% phiPrime: Angle of incidence to illuminated face (90deg)
%
% Method can be one of followings
%
%       1. Kirchhoff
%       2. Felsen
%       3. Conducting Half Plane
%       4. 90 degree Wedge
%
% ===========================================================================

%------------------------------ input parameter -----------------------------

phiPrime=90;            % incidence angle in degree

%---------------------- selection of approximation method -------------------

s=sprintf('\n\nChoose one:\n\t1.Kirchgoff\n\t2.Felsen\n');
s=sprintf('%s\t3.Cond. Half Plane\n\t4.90deg Wedge\n',s);
Method=input(s);        % Method should be 1, 2, 3 or 4

Kirchhoff=1;            % these assignments are only for readability
Felsen=2;
ConductingPlane=3;
Wedge=4;

%-------------------------------------------------------------------------------

ThetaDeg=-90:(360/511):270;
theta=ThetaDeg/180*pi;

if Method==Kirchhoff,
    D=-(1+cos(theta))./(2*sin(theta));      % Kirchhoff-Huygens
    mstr='Kirchhoff-Huygens';

elseif Method==Felsen,
    D=-1./theta+1./(-2*pi-theta);           % Felsen
    mstr='Felsen';

elseif Method==ConductingPlane,
    phi1=phiPrime/180*pi;                   % incidence angle in radian
    phi=3/2*pi-theta;
    D=-1/2*(1./cos((phi-phi1)/2)-1./cos((phi+phi1)/2)); % Cond. Half-Plane
    mstr='Cond. Half-Plane';

elseif Method==Wedge,
    ThetaDeg=-45:(360/511):225;
    theta1=ThetaDeg*pi/180;
    phi2=5/4*pi-theta1;
    phi3=phiPrime/180*pi-pi/4;              % incidence angle in radian
    D=-1/3*(cot((pi+phi2-phi3)/3)+cot((pi-phi2-phi3)/3)...
        -cot((pi+phi2+phi3)/3)-cot((pi-phi2+phi3)/3));  % 90 deg Wedge
    mstr='90deg wedge';
else
    disp('Invalid option selected');
    return;
end

%------------------------ plot diffraction coefficients ---------------------

figure(1);clf
plot(ThetaDeg,abs(D))
axis([-90 270 0 10])
set(gca,'XTick',[-90 0 90 180 270]);grid on
ylabel('|D\times(2\pik)^{0.5}|');
xlabel('angle, \theta');
title(['Diffraction Coefficients versus Diffraction Angle: ',mstr]);

%--------------------------------- end of program ---------------------------