%============================================================================
% Field-strength versus y at a plane behind a deffracting edge for
% unit amplitude plane wave at normal incidence
%
% Input parameters
%
%   f: frequency (900MHz)
%   x: distance behind edge (30m)
%   Ymin/Ymax: range of y for calculation (-10/10)
%
%   Method: approximation method for diffraction coefficients
%           1. Kirchhoff
%           2. Felsen
%           3. Cond. Plane
%
%============================================================================

f=9e8;              % frequency = 900MHz
x=30;               % distance behind edge
Ymin=-10; Ymax=10;  % range of y for calculation

%---------------------- selection of approximation method -------------------

s=sprintf('\n\nChoose one:\n\t1.Kirchgoff\n\t2.Felsen\n\t3.Cond. Half Plane\n');
Method=input(s);    % Method should be 1, 2 or 3

Kirchhoff=1;        % these assignments are only for readability
Felsen=2;
ConductingPlane=3;

%--------------------- calculate diffraction coefficients -------------------

y=Ymin:(Ymax-Ymin)/511:Ymax;    % 511 points are calculated
k=2*pi*f/3e8;                   % wave number
roh=sqrt(x.^2+y.^2);
theta=atan(y./x);
s=1/2*k.*roh.*tan(theta).^2;

if Method==Kirchhoff,
    Dtheta=-1./sqrt(2*pi.*k) .* (1./theta+1./(2*pi-theta));
    Tstr='Kirchhoff';
elseif Method==Felsen,
    Dtheta=-1./sqrt(2*pi.*k) .* (1./theta+1./(2*pi-theta));
    Tstr='Felsen';
elseif Method==ConductingPlane,
    Dtheta=-1./sqrt(2*pi.*k).*(1./cos((pi-theta)/2)-1./cos((2*pi+theta)/2))/2;
    Tstr='ConductingPlane';
else
    disp('Invalid option selected');
    return;
end

z=sqrt(2*s/pi);
f=(1+0.926.*z)./(2+1.792.*z+3.104.*z.^2);
g=1./(2+4.142.*z+3.492.*z.^2+6.670.*z.^3);
Fs=sqrt(2*pi*s).*(f+i*g);

DT=Dtheta.*Fs;

%------------------------- caculate field strength --------------------------

Field=exp(-j*k*x)*(sign(y)+1)/2 +exp(-j*pi/4)*exp(-j*k*roh)./sqrt(roh).*DT;

%------------------------------------- plot ---------------------------------

figure(1);
plot(y,20*log10(abs(Field)));
grid on
ylabel('Field Strength(dB)');
xlabel('y(meters)');
title(['Field Strength Behind a Diffracting Edge: Method = ' Tstr]);

%--------------------------------- end of program ---------------------------
