%============================================================================
% Reflection Coefficient at a Dielectric Half-Space for Different Values of
% Relative Permittivitie, er
%
% Input parameters
%
% eR: real part of permittivity epsilon ([81,15, 6, 2])
% eI: imaginary part of     "           ([ 0, 0, 0, 0])
%============================================================================
%-------------------------- input parameter assignment ----------------------

eR=[81,15,6,2];    		% real part of 4 permittivities
eI=[0,0,0,0];			% imaginary part of 4 permittivities

%------------- use pre-calulated values for repeated computation ------------

er=eR+j*eI;

Npt=512; 				% number of points to compute
SQRTer=sqrt(er);
theta=0:(pi/(2*(Npt-1))):(pi/2);
COStheta=cos(theta);
Gamma=zeros(4,Npt);     % initialize variable

%----------------------------- TE mode reflection ---------------------------

for k=1:4,
   thetaT=asin(sin(theta)/SQRTer(k));
   SQERTHETA=SQRTer(k)*cos(thetaT);
   Gamma(k,:)=(COStheta-SQERTHETA)./(COStheta+SQERTHETA);
end

thetaDeg=theta*180/pi;

%------------------------------ plotting GammaE -----------------------------

subplot(2,1,1);
plot(thetaDeg,abs(Gamma.'));
m=fix(Npt/3.5);

for k=1:4,
   str=sprintf('%s=%2.0f','\epsilon_r',er(k));
   text(thetaDeg(m),abs(Gamma(k,m)),str,'HorizontalAlignment','right',...
        'VerticalAlignment','bottom');
end
axis([0 90 0 1]);
set(gca,'xtick',[0 15 30 45 60 75 90]);
xlabel('Incident angle \theta');
ylabel('|\Gamma_E|');

%------------------------------ TM mode reflection --------------------------

for k=1:4,
   thetaT=asin(sin(theta)/SQRTer(k));
   COSthetaT=cos(thetaT);
   SQERTHETA=SQRTer(k)*COStheta;
   Gamma(k,:)=(SQERTHETA-COSthetaT)./(COSthetaT+SQERTHETA);
end

%------------------------------- plotting GammaH ----------------------------

subplot(2,1,2);
plot(thetaDeg,abs(Gamma'));

m=fix(Npt/6);

for k=1:4,
   str=sprintf('%s=%2.0f','\epsilon_r',er(k));
   text(thetaDeg(m),abs(Gamma(k,m)),str,'HorizontalAlignment','left',...
        'VerticalAlignment','bottom');
end
axis([0 90 0 1]);
set(gca,'xtick',[0 15 30 45 60 75 90]);
xlabel('Incident angle \theta');
ylabel('|\Gamma_H|');

%--------------------------------- end of program ---------------------------