%============================================================================
% Evaluating H field for plane wave propagating past building rows
% (diffraction calculation for multiple screen and incident plane wave)
%
% Input parameters:
%
%   Nmax: maximum number of screens (400)
%   limq: maximum value of q to evaluate coefficients I(N,q,1). (200)
%   gp=[0.494 0.370 0.247 0.123]
%
%============================================================================
clear
%---------------------------- input parameters ------------------------------

Nmax=400;
limq=200;
gp=[0.494 0.370 0.247 0.123];

%------------------ calculate I(N,1,1)/q! for N=1,..,Nmax -------------------

I1=zeros(Nmax,limq);
aux=1/(2*sqrt(pi));
I1(1,1)=aux;                    % I1(1,1) is I(N=M-1=1,q=1,beta=1)
I10=ones(Nmax+1,1);

for n=1:Nmax,                   % I10(n+1)=I(n,0,1)=Pockhammer(1/2,n)/n!
    I10(n+1)=I10(n)*(1/2+n-1)/n;
end                             % I(n,0,1)/q!=I(n,0,1)/0!=I(n,0,1)

for N=2:Nmax,
    Sum=0;
    for n=0:N-1,
        Sum=Sum+I10(n+1)/sqrt(N-n);
    end
    I1(N,1)=aux*Sum;
end

%----------------- calculate I(N,2,1)/q! for N=1,...,Nmax -------------------

I1(1,2)=1/4;                    % I1(1,2)=I(N=M-1=1,q=2,beta=1)
                                % I(1,0,1)=1/2;
                                % I(1,2,1)=1/2*I(1,0,1)+0
for N=2:Nmax,
    Sum=0;                      % for n=0, I(0,1,1)=0;
    for n=1:N-1,
        Sum=Sum+I1(n,1)/sqrt(N-n);
    end
    I1(N,2)=N/2*I10(N+1)+aux*Sum;
end
I1(:,2)=I1(:,2)/2;  % I1/q!  for q=2

%------------ calculate I(N,q,1)/q! for N=1,...,Nmax, q=3,...,lmiq ----------

for q=3:limq
    I1(1,q)=1/2 * I1(1,q-2)/q;  % for N=1
    for N=2:Nmax
        Sum=0;                  % Sum for n=0
        for n=1:N-1
            Sum=Sum+I1(n,q-1)/sqrt(N-n);
        end
        I1(N,q)=N/2*I1(N,q-2)/q + aux*Sum/q;
    end
    str=sprintf('I(N,q,beta=1) for q=%d of %d completed',q,limq);
    disp(str);
end

%-------------------- calculate magnitude of H field ------------------------

aux=2*sqrt(j*pi).*gp(:);
magH=zeros(length(gp),Nmax);    % gp can be a vector type
for N=1:Nmax,
    Sum=I10(N+1);               % for q=0; I(N,0,1)
    for q=1:limq,
        Sum=Sum+I1(N,q).*aux.^q;
    end
    magH(:,N)=abs(Sum);         % magnitude of H field
end

for k=1:length(gp),
    stop=fix(9.5./(gp(k).^2));  % maximum N for valid approximation
    if stop>Nmax, stop=Nmax; end
    semilogx(magH(k,1:stop));   % plot only the valid results
    hold on
end
hold off
axis([1 1000 0.3 1.1])
xlabel('N')
ylabel('|H(x_{N+1},0)|')
title('Rooftop Field for Incident Plane Wave Past Rows of Buildings')

%------------------------------ end of program ------------------------------