%============================================================================
% Reflection Coefficient for a Wall
%
% Input parameters
%
%    w: thickness of the wall (30cm)
%    f: frequency (4GHz)
%   er: relative permittivity (4.0-0.1j)
%
%============================================================================
%---------------------------- input parameters ------------------------------

w=0.3;          % thickness of the wall in meter
f=4.0e9;        % frequency in Hz
er=4.0-j*0.1;   % relative permittivity of wall

%--------------------------- start of calculation ---------------------------

C=3e8;          % velocity of light
eta0=120*pi;    % characteristic impedance of air
omega=2*pi*f;

Npt=256;        % the number of points to plot
SQRTer=sqrt(er);
theta=0:(pi/(2*(Npt-1))):(pi/2); % incident angle
COStheta=cos(theta);
thetaT=asin(sin(theta)/SQRTer);
k0=omega/C;
kw=k0*SQRTer;
kwz=kw*cos(thetaT);

xs=theta*180/pi;

%--------------------------- Gamma for TE mode ------------------------------

ZaTE=eta0./cos(theta);
ZwTE=(eta0/SQRTer)./cos(thetaT);
kzl=kwz*w;

ZlTE=ZwTE.*(ZaTE.*cos(kzl)+j*ZwTE.*sin(kzl))./(ZwTE.*cos(kzl)+j*ZaTE.*sin(kzl));

GammaTE=(ZlTE-ZaTE)./(ZlTE+ZaTE);
Y1a=abs(GammaTE);

subplot(2,1,1);
plot(xs,Y1a');
hold on

%------------------------------ w=infinity ----------------------------------

GammaTEInf=(ZwTE-ZaTE)./(ZwTE+ZaTE);
Y1b=abs(GammaTEInf);

subplot(2,1,1);
plot(xs,Y1b','--');
hold off

axis([0 90 0 1]);
set(gca,'xtick',[0 15 30 45 60 75 90]);
xlabel('Angle of Incidence \theta');
ylabel('|\Gamma_{TE}|');
title('Reflection Coefficient, TE mode')

%----------------------------- Gamma for TM mode ----------------------------

ZaTM=eta0.*cos(theta);
ZwTM=(eta0/SQRTer).*cos(thetaT);
kzl=kwz*w;

ZlTM=ZwTM.*(ZaTM.*cos(kzl)+j*ZwTM.*sin(kzl))./(ZwTM.*cos(kzl)+j*ZaTM.*sin(kzl));

GammaTM=(ZlTM-ZaTM)./(ZlTM+ZaTM);
Y2a=abs(GammaTM);

subplot(2,1,2);
plot(xs,Y2a','-');
hold on

%----------------------------- w=infinity -----------------------------------

GammaTMInf=(ZwTM-ZaTM)./(ZwTM+ZaTM);
Y2b=abs(GammaTMInf);

plot(xs,Y2b','--');
hold off

axis([0 90 0 1]);
set(gca,'xtick',[0 15 30 45 60 75 90]);
xlabel('Angle of Incidence \theta');
ylabel('|\Gamma_{TM}|');
title('Reflection Coefficient, TM mode')

%------------------------------- end of program -----------------------------
